# ShapG: a fast and exactly approach to approximate the Shaple value on graph

If you find this code useful in your research, please consider citing:

1. For centralities measures:
      ```
      @article{zhao2024centralitymeasuresopiniondynamics,
            title={Centrality measures and opinion dynamics in two-layer networks with replica nodes}, 
            author={Chi Zhao and Elena Parilina},
            year={2024},
            eprint={2406.18780},
            archivePrefix={arXiv},
            primaryClass={physics.soc-ph},
            journal={arXiv preprint arXiv:2406.18780},
            url={https://arxiv.org/abs/2406.18780}, 
      }
      ```
2. For the new method for explanable ai:
      ```
      @article{zhao2024shapgnewfeatureimportance,
            title={ShapG: new feature importance method based on the Shapley value}, 
            author={Chi Zhao and Jing Liu and Elena Parilina},
            year={2024},
            eprint={2407.00506},
            archivePrefix={arXiv},
            primaryClass={cs.AI},
            journal={arXiv preprint arXiv:2407.00506},
            url={https://arxiv.org/abs/2407.00506}, 
      }
      ```